==> phplist-2.10.3.tgz: lists/admin/lan/en/common.php <==
<?php

# file with common texts for translation

$lan = array(
  'logout' => 'Logout',
  'Main Page' => 'Main Page',
  'user' => 'User',
  'error' => 'Error',
  'version' => 'version',
  'powered by' => 'powered by',
  'fatalerror' => 'Fatal Error',
  'warning' => 'Warning',
  'information' => 'Information',
  'help' => 'help',
  'about' => 'about',
  'lists' => 'lists',
  'send a message' => 'Send a message',
  'users' => 'users',
  'manage users' => 'manage users',
  'messages' => 'messages',
  'statistics' => 'statistics',
  'process queue' => 'process queue',
  'configure' => 'configure',
  'Subscribe Pages' => 'Subscribe Pages',
  'Send a prepared message' => 'Send a prepared message',
  'Prepare a message' => 'Prepare a message',
  'Templates' => 'Templates',
  'View Bounces' => 'View Bounces',
  'Process Bounces' => 'Process Bounces',
  'Eventlog' => 'Eventlog',
  'Sunday' => 'Sunday',
  'Monday' => 'Monday',
  'Tuesday' => 'Tuesday',
  'Wednesday' => 'Wednesday',
  'Thursday' => 'Thursday',
  'Friday' => 'Friday',
  'Saturday' => 'Saturday',
  'January' => 'January',
  'February' => 'February',
  'March' => 'March',
  'April' => 'April',
  'May' => 'May',
  'June' => 'June',
  'July' => 'July',
  'August' => 'August',
  'September' => 'September',
  'October' => 'October',
  'November' => 'November',
  'December' => 'December',
  'Jan' => 'Jan',
  'Feb' => 'Feb',
  'Mar' => 'Mar',
  'Apr' => 'Apr',
  'shortMay' => 'May',
  'Jun' => 'Jun',
  'Jul' => 'Jul',
  'Aug' => 'Aug',
  'Sep' => 'Sep',
  'Oct' => 'Oct',
  'Nov' => 'Nov',
  'Dec' => 'Dec',
  # from sendemaillib
  'sendingtextonlyto' => 'Sending text only to',
  'sendingmessage' => 'Sending Message',
  'withsubject' => 'with subject',
  'to' => 'to',
  'admininitfailure' => 'Admin Authentication initialisation failure',
  'yourpassword' => 'Your password for phplist',
  'yourpasswordis' => 'Your password is',
  'passwordsent' => 'Your password has been sent by email',
  'cannotsendpassword' => 'Unable to send the password',
  'ipchanged' => 'Your IP address has changed. For security reasons, please login again',
  'goodbye' => 'goodbye',
  'goodmorning' => 'good morning',
  'goodafternoon' => 'good afternoon',
  'goodevening' => 'good evening',
  'safemodewarning' => 'In safe mode, not everything will work as expected',
  'magicquoteswarning' => 'Things will work better when PHP magic_quotes_gpc = <b>on</b>',
  'magicruntimewarning' => 'Things will work better when PHP magic_quotes_runtime = off',
  'noxml' => 'You are trying to use RSS, but XML is not included in your PHP',
  'warnopenbasedir' => 'open_basedir restrictions are in effect, which may be the cause of the next warning',
  'warnattachmentrepository' => 'The attachment repository does not exist or is not writable',
  'nofpdf' => 'You are trying to use PDF support without having FPDF loaded',
  'warnpageroot' => 'The pageroot in your config does not match the current location<br/>Check your config file.',
  'pagenotfoundinplugin' => 'Sorry this page was not found in the plugin',
  'notimplemented' => 'Sorry not Implemented yet',
  'noaccess' => 'You do not have enough privileges to access this page',
  'nohelpavailable' => 'Sorry, help for this topic is not available yet: ',
  'closewindow' => 'Close this window',
  'success' => 'success',
  'failed' => 'failed',
  'default login is' => 'Default login is',
  'with password' => 'with password',
  'name' => 'Name',
  'password' => 'Password',
  'enter' => 'Enter',
  'forgot password' => 'Forgot Password?',
  'enter your email' => 'Enter your email',
  'send password' => 'Send Password',
  'An image exists on the server, check this box to keep the existing one' => 'An image exists on the server, check this box to keep the existing one',
  'View Image' => 'View Image',
  'Upload new image' => 'Upload new image',
  'textline' => 'textline',
  'textarea' => 'textarea',
  'date' => 'date',
  'checkbox' => 'checkbox',
  'radio' => 'radio',
  'select' => 'select',
  'checkboxgroup' => 'checkboxgroup',
  'unnamed list' => 'Unnamed List',
  'unknown' => 'Unknown',
  'very little time' => 'very little time',
  'A process for this page is already running and it was still alive' => 'A process for this page is already running and it was still alive',
  'seconds ago' => 'seconds ago',
  'We have been waiting too long, I guess the other process is still going ok' => 'We have been waiting too long, I guess the other process is still going ok',
  'Sleeping for 20 seconds, aborting will quit' => 'Sleeping for 20 seconds, aborting will quit',
  'No Image was found' => 'No Image was found',
  'messages' => 'Messages',
  'bounces' => 'Bounces',
  'bounce' => 'bounce',
  'msg' => 'msg', # as in short for message
  'time' => 'time',
  'sent' => 'sent',
  'text' => 'text',
  'html' => 'html',
  #
  # new for 2.9.5
  'delete user' => 'delete user',
  'unconfirm user' => 'unconfirm user',
  'delete user and bounce' => 'delete user and bounce',
  'unconfirm user and delete bounce' => 'unconfirm user and delete bounce',
  'blacklist user and delete bounce' => 'blacklist user and delete bounce',
  'delete bounce' => 'delete bounce',
  'blacklist user' => 'blacklist user',
  'manage bounces' => 'Manage Bounces',
  'perc' => '%',
  'invalid login from %s, tried logging in as %s' => 'invalid login from %s, tried logging in as %s',
  'successful password request from %s for %s' => 'successful password request from %s for %s',
  'failed password request from %s for %s' => 'failed password request from %s for %s',
  'login ip invalid from %s for %s (was %s)' => 'login ip invalid from %s for %s (was %s)',
  'invalidated login from %s for %s (error %s)' => 'invalidated login from %s for %s (error %s)',
  'close' => 'close',
  'open' => 'open',
  'import is not available' => 'import is not available',

  # new for 2.10.0
  'Please wait, upgrading your database, do not interrupt' => 'Please wait, upgrading your database, do not interrupt',
  'purgerss' => 'purgerss',
  'Purge RSS items' => 'Purge RSS items',
  'In order to login, you need to enable cookies in your browser' => 'In order to login, you need to enable cookies in your browser',

  # added 2.10.2
  'globalvulnwarning' => 'Your version of PHP has a major security issue.<br/>It is best to upgrade to the latest version of PHP. <a href="http://www.hardened-php.net/globals-problem">Read More</a> about this issue.',

);

?>

==> phplist-2.10.5p0.tgz: lists/admin/lan/en/common.php <==
<?php

# file with common texts for translation

$lan = array(
  'logout' => 'Logout',
  'Main Page' => 'Main Page',
  'user' => 'User',
  'error' => 'Error',
  'version' => 'version',
  'powered by' => 'powered by',
  'fatalerror' => 'Fatal Error',
  'warning' => 'Warning',
  'information' => 'Information',
  'help' => 'help',
  'about' => 'about',
  'lists' => 'lists',
  'send a message' => 'Send a message',
  'users' => 'users',
  'manage users' => 'manage users',
  'messages' => 'messages',
  'statistics' => 'statistics',
  'process queue' => 'process queue',
  'configure' => 'configure',
  'Subscribe Pages' => 'Subscribe Pages',
  'Send a prepared message' => 'Send a prepared message',
  'Prepare a message' => 'Prepare a message',
  'Templates' => 'Templates',
  'View Bounces' => 'View Bounces',
  'Process Bounces' => 'Process Bounces',
  'Eventlog' => 'Eventlog',
  'Sunday' => 'Sunday',
  'Monday' => 'Monday',
  'Tuesday' => 'Tuesday',
  'Wednesday' => 'Wednesday',
  'Thursday' => 'Thursday',
  'Friday' => 'Friday',
  'Saturday' => 'Saturday',
  'January' => 'January',
  'February' => 'February',
  'March' => 'March',
  'April' => 'April',
  'May' => 'May',
  'June' => 'June',
  'July' => 'July',
  'August' => 'August',
  'September' => 'September',
  'October' => 'October',
  'November' => 'November',
  'December' => 'December',
  'Jan' => 'Jan',
  'Feb' => 'Feb',
  'Mar' => 'Mar',
  'Apr' => 'Apr',
  'shortMay' => 'May',
  'Jun' => 'Jun',
  'Jul' => 'Jul',
  'Aug' => 'Aug',
  'Sep' => 'Sep',
  'Oct' => 'Oct',
  'Nov' => 'Nov',
  'Dec' => 'Dec',
  # from sendemaillib
  'sendingtextonlyto' => 'Sending text only to',
  'sendingmessage' => 'Sending Message',
  'withsubject' => 'with subject',
  'to' => 'to',
  'admininitfailure' => 'Admin Authentication initialisation failure',
  'yourpassword' => 'Your password for phplist',
  'yourpasswordis' => 'Your password is',
  'passwordsent' => 'Your password has been sent by email',
  'cannotsendpassword' => 'Unable to send the password',
  'ipchanged' => 'Your IP address has changed. For security reasons, please login again',
  'goodbye' => 'goodbye',
  'goodmorning' => 'good morning',
  'goodafternoon' => 'good afternoon',
  'goodevening' => 'good evening',
  'safemodewarning' => 'In safe mode, not everything will work as expected',
  'magicquoteswarning' => 'Things will work better when PHP magic_quotes_gpc = <b>on</b>',
  'magicruntimewarning' => 'Things will work better when PHP magic_quotes_runtime = off',
  'noxml' => 'You are trying to use RSS, but XML is not included in your PHP',
  'warnopenbasedir' => 'open_basedir restrictions are in effect, which may be the cause of the next warning',
  'warnattachmentrepository' => 'The attachment repository does not exist or is not writable',
  'nofpdf' => 'You are trying to use PDF support without having FPDF loaded',
  'warnpageroot' => 'The pageroot in your config does not match the current location<br/>Check your config file.',
  'pagenotfoundinplugin' => 'Sorry this page was not found in the plugin',
  'notimplemented' => 'Sorry not Implemented yet',
  'noaccess' => 'You do not have enough privileges to access this page',
  'nohelpavailable' => 'Sorry, help for this topic is not available yet: ',
  'closewindow' => 'Close this window',
  'success' => 'success',
  'failed' => 'failed',
  'default login is' => 'Default login is',
  'with password' => 'with password',
  'name' => 'Name',
  'password' => 'Password',
  'enter' => 'Enter',
  'forgot password' => 'Forgot Password?',
  'enter your email' => 'Enter your email',
  'send password' => 'Send Password',
  'An image exists on the server, check this box to keep the existing one' => 'An image exists on the server, check this box to keep the existing one',
  'View Image' => 'View Image',
  'Upload new image' => 'Upload new image',
  'textline' => 'textline',
  'textarea' => 'textarea',
  'date' => 'date',
  'checkbox' => 'checkbox',
  'radio' => 'radio',
  'select' => 'select',
  'checkboxgroup' => 'checkboxgroup',
  'unnamed list' => 'Unnamed List',
  'unknown' => 'Unknown',
  'very little time' => 'very little time',
  'A process for this page is already running and it was still alive' => 'A process for this page is already running and it was still alive',
  'seconds ago' => 'seconds ago',
  'We have been waiting too long, I guess the other process is still going ok' => 'We have been waiting too long, I guess the other process is still going ok',
  'Sleeping for 20 seconds, aborting will quit' => 'Sleeping for 20 seconds, aborting will quit',
  'No Image was found' => 'No Image was found',
  'messages' => 'Messages',
  'bounces' => 'Bounces',
  'bounce' => 'bounce',
  'msg' => 'msg', # as in short for message
  'time' => 'time',
  'sent' => 'sent',
  'text' => 'text',
  'html' => 'html',
  #
  # new for 2.9.5
  'delete user' => 'delete user',
  'unconfirm user' => 'unconfirm user',
  'delete user and bounce' => 'delete user and bounce',
  'unconfirm user and delete bounce' => 'unconfirm user and delete bounce',
  'blacklist user and delete bounce' => 'blacklist user and delete bounce',
  'delete bounce' => 'delete bounce',
  'blacklist user' => 'blacklist user',
  'manage bounces' => 'Manage Bounces',
  'perc' => '%',
  'invalid login from %s, tried logging in as %s' => 'invalid login from %s, tried logging in as %s',
  'successful password request from %s for %s' => 'successful password request from %s for %s',
  'failed password request from %s for %s' => 'failed password request from %s for %s',
  'login ip invalid from %s for %s (was %s)' => 'login ip invalid from %s for %s (was %s)',
  'invalidated login from %s for %s (error %s)' => 'invalidated login from %s for %s (error %s)',
  'close' => 'close',
  'open' => 'open',
  'import is not available' => 'import is not available',

  # new for 2.10.0
  'Please wait, upgrading your database, do not interrupt' => 'Please wait, upgrading your database, do not interrupt',
  'purgerss' => 'purgerss',
  'Purge RSS items' => 'Purge RSS items',
  'In order to login, you need to enable cookies in your browser' => 'In order to login, you need to enable cookies in your browser',

  # added 2.10.2
  'globalvulnwarning' => 'Your version of PHP has a major security issue.<br/>It is best to upgrade to the latest version of PHP. <a href="http://www.hardened-php.net/globals-problem">Read More</a> about this issue.',

  # added 2.10.4

  # note to translators, this is part of a plain text email, so do not use html
  'spamblockemailintro' => '

--------------------------------------------------------------------------------
This is a notification of a possible spam attack to your phplist subscribe page.
The data submitted has been copied below, so you can check whether this was actually the case.
The submitted data has been converted into non-html characters, for security reasons.

If you want to stop receiving this message, set 

  define(\'NOTIFY_SPAM\',0);

in your phplist config file.

This user has not been added to the database. If there is an error, you will need to 
add them manually. 
--------------------------------------------------------------------------------

',


);

?>
